@@ -8,3 +8,11 @@ class IndexDoesNotFoundError(Exception):
 
 class InvalidElasticsearchResponse(Exception):
     ...
+
+
+class InvalidModelError(Exception):
+    ...
+
+
+class BulkError(Exception):
+    ...
